(sec-tskit2zarr)=
# tskit2zarr

Convert tskit data to the
[VCF Zarr specification](https://github.com/sgkit-dev/vcf-zarr-spec/)
reliably in parallel.

See {ref}`sec-tskit2zarr-cli-ref` for detailed documentation on
command line options.

